==> persisted_bloc_stream-4.2.5.tar.gz: lib/persisted_bloc_stream.dart <==
library persisted_bloc_stream;

import 'dart:convert';

import 'package:bloc_stream/bloc_stream.dart';
import 'package:dartz/dartz.dart';

import 'storage.dart';
export 'storage.dart';

class UnassignedStorageException implements Exception {
  UnassignedStorageException();

  static final message = '''
    PersistedBlocStream.storage has not been assigned.
    Please ensure you have initialized and assigned a Storage instance.
    E.g.
    PersistedBlocStream.storage = await HiveStorage.build();
  ''';

  @override
  String toString() => "UnassignedStorageException: $message";
}

abstract class PersistedBlocStream<State> extends BlocStream<State> {
  PersistedBlocStream(State initialValue) : super(initialValue);

  static Storage storage;
  static bool get _hasStorage => storage != null;

  String get storageKey => runtimeType.toString();

  Option<State> _readValue() {
    if (!_hasStorage) throw UnassignedStorageException();

    return storage
        .read(storageKey)
        .bind((json) => catching(() => fromJson(jsonDecode(json))).toOption());
  }

  @override
  State get initialValueOverride => _readValue().getOrElse(() => null);

  @override
  void willUpdateValue(State current, State next) {
    if (!_hasStorage) throw UnassignedStorageException();

    catching(() => jsonEncode(toJson(next))).map((json) => optionOf(json).fold(
          () => storage.delete(storageKey),
          (encodedJson) => storage.write(storageKey, encodedJson),
        ));

    super.willUpdateValue(current, next);
  }

  State fromJson(dynamic json);
  dynamic toJson(State value);
}

==> persisted_bloc_stream-4.2.6.tar.gz: lib/persisted_bloc_stream.dart <==
library persisted_bloc_stream;

import 'dart:convert';

import 'package:bloc_stream/bloc_stream.dart';
import 'package:dartz/dartz.dart';

import 'storage.dart';
export 'storage.dart';

class UnassignedStorageException implements Exception {
  UnassignedStorageException();

  static final message = '''
    PersistedBlocStream.storage has not been assigned.
    Please ensure you have initialized and assigned a Storage instance.
    E.g.
    PersistedBlocStream.storage = await HiveStorage.build();
  ''';

  @override
  String toString() => "UnassignedStorageException: $message";
}

abstract class PersistedBlocStream<State> extends BlocStream<State> {
  PersistedBlocStream(State initialValue) : super(initialValue);

  static Storage storage;
  static bool get _storageMissing => optionOf(storage).isNone();

  String get storageKey => runtimeType.toString();

  Option<State> _readValue() {
    if (_storageMissing) throw UnassignedStorageException();

    return storage
        .read(storageKey)
        .bind((json) => catching(() => fromJson(jsonDecode(json))).toOption());
  }

  @override
  State get initialValueOverride => _readValue().getOrElse(() => null);

  @override
  void willUpdateValue(State current, State next) {
    if (_storageMissing) throw UnassignedStorageException();

    catching(() => jsonEncode(toJson(next))).map((json) => optionOf(json).fold(
          () => storage.delete(storageKey),
          (encodedJson) => storage.write(storageKey, encodedJson),
        ));

    super.willUpdateValue(current, next);
  }

  State fromJson(dynamic json);
  dynamic toJson(State value);
}
